[llvm] r173725 - Try to appease some broken compilers by using 'unsigned' instead of 'uint64_t'.

Bill Wendling isanbard at gmail.com
Mon Jan 28 14:33:39 PST 2013


Author: void
Date: Mon Jan 28 16:33:39 2013
New Revision: 173725

URL: http://llvm.org/viewvc/llvm-project?rev=173725&view=rev
Log:
Try to appease some broken compilers by using 'unsigned' instead of 'uint64_t'.

Modified:
    llvm/trunk/include/llvm/IR/Attributes.h
    llvm/trunk/lib/IR/AttributeImpl.h
    llvm/trunk/lib/IR/Attributes.cpp

Modified: llvm/trunk/include/llvm/IR/Attributes.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/IR/Attributes.h?rev=173725&r1=173724&r2=173725&view=diff
==============================================================================
--- llvm/trunk/include/llvm/IR/Attributes.h (original)
+++ llvm/trunk/include/llvm/IR/Attributes.h Mon Jan 28 16:33:39 2013
@@ -108,7 +108,7 @@ public:
   Attribute() : pImpl(0) {}
 
   /// \brief Return a uniquified Attribute object.
-  static Attribute get(LLVMContext &Context, ArrayRef<AttrKind> Kinds);
+  static Attribute get(LLVMContext &Context, AttrKind Kind);
   static Attribute get(LLVMContext &Context, AttrBuilder &B);
 
   /// \brief Return a uniquified Attribute object that has the specific
@@ -203,13 +203,13 @@ private:
 
   /// \brief Create an AttributeSet with the specified parameters in it.
   static AttributeSet get(LLVMContext &C,
-                          ArrayRef<std::pair<uint64_t, Attribute> > Attrs);
+                          ArrayRef<std::pair<unsigned, Attribute> > Attrs);
   static AttributeSet get(LLVMContext &C,
-                          ArrayRef<std::pair<uint64_t,
+                          ArrayRef<std::pair<unsigned,
                                              AttributeSetNode*> > Attrs);
 
   static AttributeSet getImpl(LLVMContext &C,
-                              ArrayRef<std::pair<uint64_t,
+                              ArrayRef<std::pair<unsigned,
                                                  AttributeSetNode*> > Attrs);
 
 

Modified: llvm/trunk/lib/IR/AttributeImpl.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/IR/AttributeImpl.h?rev=173725&r1=173724&r2=173725&view=diff
==============================================================================
--- llvm/trunk/lib/IR/AttributeImpl.h (original)
+++ llvm/trunk/lib/IR/AttributeImpl.h Mon Jan 28 16:33:39 2013
@@ -116,7 +116,7 @@ class AttributeSetImpl : public FoldingS
 
   LLVMContext &Context;
 
-  typedef std::pair<uint64_t, AttributeSetNode*> IndexAttrPair;
+  typedef std::pair<unsigned, AttributeSetNode*> IndexAttrPair;
   SmallVector<IndexAttrPair, 4> AttrNodes;
 
   // AttributesSet is uniqued, these should not be publicly available.
@@ -124,7 +124,7 @@ class AttributeSetImpl : public FoldingS
   AttributeSetImpl(const AttributeSetImpl &) LLVM_DELETED_FUNCTION;
 public:
   AttributeSetImpl(LLVMContext &C,
-                   ArrayRef<std::pair<uint64_t, AttributeSetNode*> > attrs)
+                   ArrayRef<std::pair<unsigned, AttributeSetNode*> > attrs)
     : Context(C), AttrNodes(attrs.begin(), attrs.end()) {}
 
   /// \brief Get the context that created this AttributeSetImpl.
@@ -166,7 +166,7 @@ public:
     Profile(ID, AttrNodes);
   }
   static void Profile(FoldingSetNodeID &ID,
-                      ArrayRef<std::pair<uint64_t, AttributeSetNode*> > Nodes) {
+                      ArrayRef<std::pair<unsigned, AttributeSetNode*> > Nodes) {
     for (unsigned i = 0, e = Nodes.size(); i != e; ++i) {
       ID.AddInteger(Nodes[i].first);
       ID.AddPointer(Nodes[i].second);

Modified: llvm/trunk/lib/IR/Attributes.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/IR/Attributes.cpp?rev=173725&r1=173724&r2=173725&view=diff
==============================================================================
--- llvm/trunk/lib/IR/Attributes.cpp (original)
+++ llvm/trunk/lib/IR/Attributes.cpp Mon Jan 28 16:33:39 2013
@@ -31,12 +31,9 @@ using namespace llvm;
 // Attribute Implementation
 //===----------------------------------------------------------------------===//
 
-Attribute Attribute::get(LLVMContext &Context, ArrayRef<AttrKind> Kinds) {
+Attribute Attribute::get(LLVMContext &Context, AttrKind Kind) {
   AttrBuilder B;
-  for (ArrayRef<AttrKind>::iterator I = Kinds.begin(), E = Kinds.end();
-       I != E; ++I)
-    B.addAttribute(*I);
-  return Attribute::get(Context, B);
+  return Attribute::get(Context, B.addAttribute(Kind));
 }
 
 Attribute Attribute::get(LLVMContext &Context, AttrBuilder &B) {
@@ -564,7 +561,7 @@ AttributeSet AttributeSet::getParamAttri
   // FIXME: Remove.
   return pImpl && hasAttributes(Idx) ?
     AttributeSet::get(pImpl->getContext(),
-                      ArrayRef<std::pair<uint64_t, Attribute> >(
+                      ArrayRef<std::pair<unsigned, Attribute> >(
                         std::make_pair(Idx, getAttributes(Idx)))) :
     AttributeSet();
 }
@@ -573,7 +570,7 @@ AttributeSet AttributeSet::getRetAttribu
   // FIXME: Remove.
   return pImpl && hasAttributes(ReturnIndex) ?
     AttributeSet::get(pImpl->getContext(),
-                      ArrayRef<std::pair<uint64_t, Attribute> >(
+                      ArrayRef<std::pair<unsigned, Attribute> >(
                         std::make_pair(ReturnIndex,
                                        getAttributes(ReturnIndex)))) :
     AttributeSet();
@@ -583,14 +580,14 @@ AttributeSet AttributeSet::getFnAttribut
   // FIXME: Remove.
   return pImpl && hasAttributes(FunctionIndex) ?
     AttributeSet::get(pImpl->getContext(),
-                      ArrayRef<std::pair<uint64_t, Attribute> >(
+                      ArrayRef<std::pair<unsigned, Attribute> >(
                         std::make_pair(FunctionIndex,
                                        getAttributes(FunctionIndex)))) :
     AttributeSet();
 }
 
 AttributeSet AttributeSet::getImpl(LLVMContext &C,
-                                   ArrayRef<std::pair<uint64_t,
+                                   ArrayRef<std::pair<unsigned,
                                                    AttributeSetNode*> > Attrs) {
   LLVMContextImpl *pImpl = C.pImpl;
   FoldingSetNodeID ID;
@@ -611,7 +608,7 @@ AttributeSet AttributeSet::getImpl(LLVMC
 }
 
 AttributeSet AttributeSet::get(LLVMContext &C,
-                               ArrayRef<std::pair<uint64_t, Attribute> > Attrs){
+                               ArrayRef<std::pair<unsigned, Attribute> > Attrs){
   // If there are no attributes then return a null AttributesList pointer.
   if (Attrs.empty())
     return AttributeSet();
@@ -625,12 +622,12 @@ AttributeSet AttributeSet::get(LLVMConte
   }
 #endif
 
   // Create a vector if (uint64_t, AttributeSetNode*) pairs from the attributes
   // list.
-  SmallVector<std::pair<uint64_t, AttributeSetNode*>, 8> AttrPairVec;
-  for (ArrayRef<std::pair<uint64_t, Attribute> >::iterator I = Attrs.begin(),
+  SmallVector<std::pair<unsigned, AttributeSetNode*>, 8> AttrPairVec;
+  for (ArrayRef<std::pair<unsigned, Attribute> >::iterator I = Attrs.begin(),
          E = Attrs.end(); I != E; ) {
-    uint64_t Index = I->first;
+    unsigned Index = I->first;
     SmallVector<Attribute, 4> AttrVec;
     while (I->first == Index && I != E) {
       AttrVec.push_back(I->second);
@@ -645,7 +642,7 @@ AttributeSet AttributeSet::get(LLVMConte
 }
 
 AttributeSet AttributeSet::get(LLVMContext &C,
-                               ArrayRef<std::pair<uint64_t,
+                               ArrayRef<std::pair<unsigned,
                                                   AttributeSetNode*> > Attrs) {
   // If there are no attributes then return a null AttributesList pointer.
   if (Attrs.empty())
@@ -657,13 +654,13 @@ AttributeSet AttributeSet::get(LLVMConte
 AttributeSet AttributeSet::get(LLVMContext &C, unsigned Idx, AttrBuilder &B) {
   if (!B.hasAttributes())
     return AttributeSet();
-  return get(C, ArrayRef<std::pair<uint64_t, Attribute> >(
+  return get(C, ArrayRef<std::pair<unsigned, Attribute> >(
                std::make_pair(Idx, Attribute::get(C, B))));
 }
 
 AttributeSet AttributeSet::get(LLVMContext &C, unsigned Idx,
                                ArrayRef<Attribute::AttrKind> Kind) {
-  SmallVector<std::pair<uint64_t, Attribute>, 8> Attrs;
+  SmallVector<std::pair<unsigned, Attribute>, 8> Attrs;
   for (ArrayRef<Attribute::AttrKind>::iterator I = Kind.begin(),
          E = Kind.end(); I != E; ++I)
     Attrs.push_back(std::make_pair(Idx, Attribute::get(C, *I)));
@@ -671,7 +668,7 @@ AttributeSet AttributeSet::get(LLVMConte
 }
 
 AttributeSet AttributeSet::get(LLVMContext &C, ArrayRef<AttributeSet> Attrs) {
-  SmallVector<std::pair<uint64_t, AttributeSetNode*>, 8> AttrNodeVec;
+  SmallVector<std::pair<unsigned, AttributeSetNode*>, 8> AttrNodeVec;
   for (unsigned I = 0, E = Attrs.size(); I != E; ++I) {
     AttributeSet AS = Attrs[I];
     if (!AS.pImpl) continue;
@@ -625,12 +622,12 @@ AttributeSet AttributeSet::get(LLVMConte
 #endif
 
-  // Create a vector if (uint64_t, AttributeSetNode*) pairs from the attributes
+  // Create a vector if (unsigned, AttributeSetNode*) pairs from the attributes
   // list.





More information about the llvm-commits mailing list